@@ -67,13 +67,36 @@ def test_process_config(configrep):
 
 
 def test_get_required(configrep):
-    """Test getting list of requirements."""
+    """Test getting list of requirements, including extra packages
+    (such as those marked with "test", "check", "docs")."""
     if platform.system().lower() == "windows":
         assert set(configrep.get_required()) == set(
-            ["backoff", "click", "pyyaml", "defusedxml", "pypiwin32", "six"]
+            [
+                "backoff",
+                "click",
+                "pyyaml",
+                "defusedxml",
+                "pypiwin32",
+                "six",
+                "pytest",
+                "flake8",
+                "sphinx",
+            ]
         )
     else:
         assert set(configrep.get_required()) == set(
+            ["backoff", "click", "six", "pyyaml", "pytest", "flake8", "sphinx"]
+        )
+
+
+def test_get_required_no_extras(configrep):
+    """Test getting list of requirements."""
+    if platform.system().lower() == "windows":
+        assert set(configrep.get_required(include_extras_require=False)) == set(
+            ["backoff", "click", "pyyaml", "defusedxml", "pypiwin32", "six"]
+        )
+    else:
+        assert set(configrep.get_required(include_extras_require=False)) == set(
             ["backoff", "click", "six", "pyyaml"]
         )
 
